import React, { useState, useEffect } from 'react';
import styled from 'styled-components';
import axios from 'axios';
import Grid from '@material-ui/core/Grid';
import SearchInput from './SearchInput.js';
import ResourceCard from './ResourceCard.js';
import { apiUrl } from '../../env';
import SmallFooter from './SmallFooter.js';

export default function DrawerContent(props) {
	const [resources, setResources] = useState([]);

	const search = (query) => {
		axios.get(`${apiUrl}/search?
			page=0&results_per_page=5&query=${query}&search_class=LearningObject`)
			.then(res => {
				setResources(res.data);
			});
	}

	useEffect(() => {
		search(props.tag);
		}, [props.tag]);

	useEffect(() => {
		console.log(resources);
	}, [resources]);

	return(
		<Wrapper container
			direction="row"
			justify="center"
			alignItems="flex-start"
		>
			<Grid item xs={11}>
				<SearchInput stdin={props.tag} search={search}/>
			</Grid> 
			<Grid item xs={11}>
				<Description>
					Recursos Relacionados na Plataforma MEC:
				</Description>
			</Grid>
			{resources.map(r => {
				return(
					<Grid item xs={11}>
						<ResourceCard
							id={r.id}
							name={r.name}
							likes={r.likes_count}
						/>
					</Grid>
				);}
			)}
			<Grid item xs={12}>
				<SmallFooter />
			</Grid>
		</Wrapper>
		);
}

const Wrapper=styled(Grid)`
	min-width: 400px;
	max-width: 400px;
	background-color: #666;
	height: 100%;
	overflow-x: scroll !important;
`
const Description=styled.p`
	color: white;
	margin-left: 20px !important;
	margin-right: 20px !important;
`
